@@ -48,7 +48,7 @@ use AnyEvent::Handle ();
 
 use base Exporter::;
 
-our $VERSION = 2.22;
+our $VERSION = 2.23;
 
 our @EXPORT = qw(http_get http_post http_head http_request);
 
@@ -897,7 +897,7 @@ sub http_request($$@) {
             my $loc = $hdr{location};
 
             if ($loc =~ m%^//%) { # //
-               $loc = "$rscheme:$loc";
+               $loc = "$uscheme:$loc";
 
             } elsif ($loc eq "") {
                $loc = $url;
@@ -906,7 +906,7 @@ sub http_request($$@) {
                $loc =~ s/^\.\/+//;
 
                if ($loc !~ m%^[.?#]%) {
-                  my $prefix = "$rscheme://$uhost:$uport";
+                  my $prefix = "$uscheme://$uhost:$uport";
 
                   unless ($loc =~ s/^\///) {
                      $prefix .= $upath;
@@ -1463,8 +1463,6 @@ be retried, and C<1> if it was successful.
       my %hdr;
       my $ofs = 0;
 
-      warn stat $fh;
-      warn -s _;
       if (stat $fh and -s _) {
          $ofs = -s _;
          warn "-s is ", $ofs;
@@ -1502,7 +1500,7 @@ be retried, and C<1> if it was successful.
             my $status = $hdr->{Status};
 
             if (my $time = AnyEvent::HTTP::parse_date $hdr->{"last-modified"}) {
-               utime $fh, $time, $time;
+               utime $time, $time, $fh;
             }
 
             if ($status == 200 || $status == 206 || $status == 416) {
